@@ -8,10 +8,7 @@ import getpass;
 import sys, argparse;
 from datetime import datetime;
 import pdfkit
-#from wkhtmltopdf import WKHtmlToPdf
 from sys import stdout as out;
-#from oauth2client.client import SignedJwtAssertionCredentials
-#from oauth2client.client import ServiceAccountCredentials
 from oauth2client.service_account import ServiceAccountCredentials
 import json
 import imgkit
@@ -45,10 +42,12 @@ renderer = pystache.Renderer();
 
 def parse(template, base):
     tqdm.write("Reading Template: " + template)
+    base = pathlib.Path(base).expanduser()
     t = open(base.joinpath(template), 'r')
-    text = t.read();
-    t.close();
-    return pystache.parse(text);
+    text = t.read()
+    t.close()
+    return pystache.parse(text)
+
 
 def render(myParsed, hash, fullFileName=None, save_as_file=False):
     content = renderer.render(myParsed, hash);
@@ -58,6 +57,7 @@ def render(myParsed, hash, fullFileName=None, save_as_file=False):
         outputFile.close();
     return content
 
+
 def createDirs(parentFolder, filename):
     fullFileName = parentFolder + filename;
     directory = os.path.dirname(fullFileName);
@@ -65,6 +65,7 @@ def createDirs(parentFolder, filename):
         os.makedirs(directory);
     return fullFileName;
 
+
 def checkHeader(key, invheader):
     if (key not in invheader):
         tqdm.write("Your sheet does not have a column with name: " + key + ".")
@@ -77,8 +78,12 @@ def checkHeader(key, invheader):
 # 	print("Usage: " + sys.argv[0] + " <output folder> <spreadsheet name> <worksheet name> <login> [<password>]")
 # 	exit(1);
 
-parentFolder = str(args.output)  
-scope = ['https://spreadsheets.google.com/feeds']
+
+parentFolder = str(args.output)
+scope = [
+    'https://www.googleapis.com/auth/spreadsheets',
+    'https://www.googleapis.com/auth/drive'
+]
 credentials = ServiceAccountCredentials.from_json_keyfile_name(args.key, scope);
 
 
@@ -168,7 +173,7 @@ def main():
             htmlfile = hash['html_done_status'];
             html_content = render(parsed, hash, save_as_file=False);
 
-        else:
+        elif (hash.get('html_done_status', '') == '' ):
             tqdm.write('Generating the HTML: ');
             htmlfile = createDirs(baseFolder + "/html/", filename + ".html");
 
@@ -191,11 +196,13 @@ def main():
                         'orientation': 'Landscape',
                         'enable-local-file-access': '',
                         'quiet': '',
-                        'page-size': 'Letter',
+                        'page-size': 'A4',
+                        'dpi': 400,
                         'margin-bottom': '0',
                         'margin-top': '0',
                         'margin-left': '0',
                         'margin-right': '0',
+                        'disable-smart-shrinking': '',
                     }
                 );
             wks.update_cell(i+1, pdf_done_status+1,  pdffile);
